==> selenium-selenium-4.39.0.gh.tar.gz: selenium-selenium-4.39.0/dotnet/src/webdriver/BiDi/Network/SetCacheBehaviorCommand.cs <==
// <copyright file="SetCacheBehaviorCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using OpenQA.Selenium.BiDi.Json.Converters;
using System.Collections.Generic;
using System.Text.Json.Serialization;

namespace OpenQA.Selenium.BiDi.Network;

internal sealed class SetCacheBehaviorCommand(SetCacheBehaviorParameters @params)
    : Command<SetCacheBehaviorParameters, SetCacheBehaviorResult>(@params, "network.setCacheBehavior");

internal sealed record SetCacheBehaviorParameters(CacheBehavior CacheBehavior, IEnumerable<BrowsingContext.BrowsingContext>? Contexts) : Parameters;

public sealed class SetCacheBehaviorOptions : CommandOptions
{
    public SetCacheBehaviorOptions()
    {

    }

    internal SetCacheBehaviorOptions(BrowsingContextSetCacheBehaviorOptions? options)
    {

    }

    public IEnumerable<BrowsingContext.BrowsingContext>? Contexts { get; set; }
}

public sealed record BrowsingContextSetCacheBehaviorOptions;

[JsonConverter(typeof(CamelCaseEnumConverter<CacheBehavior>))]
public enum CacheBehavior
{
    Default,
    Bypass
}

public sealed record SetCacheBehaviorResult : EmptyResult;

==> selenium-selenium-4.40.0.gh.tar.gz: selenium-selenium-4.40.0/dotnet/src/webdriver/BiDi/Network/SetCacheBehaviorCommand.cs <==
// <copyright file="SetCacheBehaviorCommand.cs" company="Selenium Committers">
// Licensed to the Software Freedom Conservancy (SFC) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The SFC licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
// </copyright>

using OpenQA.Selenium.BiDi.Json.Converters;
using System.Collections.Generic;
using System.Text.Json.Serialization;

namespace OpenQA.Selenium.BiDi.Network;

internal sealed class SetCacheBehaviorCommand(SetCacheBehaviorParameters @params)
    : Command<SetCacheBehaviorParameters, SetCacheBehaviorResult>(@params, "network.setCacheBehavior");

internal sealed record SetCacheBehaviorParameters(CacheBehavior CacheBehavior, IEnumerable<BrowsingContext.BrowsingContext>? Contexts) : Parameters;

public sealed class SetCacheBehaviorOptions() : CommandOptions
{
    internal SetCacheBehaviorOptions(BrowsingContextSetCacheBehaviorOptions? options) : this()
    {

    }

    public IEnumerable<BrowsingContext.BrowsingContext>? Contexts { get; set; }
}

public sealed record BrowsingContextSetCacheBehaviorOptions;

[JsonConverter(typeof(CamelCaseEnumConverter<CacheBehavior>))]
public enum CacheBehavior
{
    Default,
    Bypass
}

public sealed record SetCacheBehaviorResult : EmptyResult;
